package de.devloop.mavor;

import java.io.IOException;
import java.io.InputStream;
import java.util.Objects;
import java.util.Properties;

public class Configuration {

    private static final String DEVELOPMENT_PROPERTIES = "development.properties";

    private static final String ENV_MAVEN_EXECUTABLE = "MAVOR_MAVEN_EXECUTABLE";
    private static final String ENV_TEMP_DIR = "MAVOR_TEMP_DIR";

    private String mavenExecutable;
    private String tempDir;

    public Configuration() throws IOException {
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
        InputStream developmentPropertiesStream = classLoader.getResourceAsStream(DEVELOPMENT_PROPERTIES);
        if (Objects.nonNull(developmentPropertiesStream)) {
            Properties developmentProperties = new Properties();
            developmentProperties.load(developmentPropertiesStream);
            initByProperties(developmentProperties);
        } else {
            initByProperties(System.getProperties());
        }
    }

    private void initByProperties(Properties properties) {
        mavenExecutable = properties.getProperty(ENV_MAVEN_EXECUTABLE);
        tempDir = properties.getProperty(ENV_TEMP_DIR);
    }

    public String getMavenExecutable() {
        return mavenExecutable;
    }

    public String getTempDir() {
        return tempDir;
    }
}